@@ -26,14 +26,14 @@ import os,sys,re
 from random import randint
 from .sqlitedb import *
 from .sqlite_utils import *
-from opensitua_core import system_mail,sformat
+from opensitua_core import system_mail
 
 
 class UsersDB(SqliteDB):
     """
     UsersDB - a class with common base methods
     """
-    def __init__(self, dsn=":memory:", modules="", fileconf="", verbose=False):
+    def __init__(self, dsn=":memory:", modules="", fileconf="", filekey="", verbose=False):
         """
         Constructor
         """
@@ -41,7 +41,7 @@ class UsersDB(SqliteDB):
         self.create_function("md5", 1, sqlite_md5 )
         self.__create_structure__(verbose)
         self.fileconf = fileconf
-
+        self.filekey  = filekey
 
     def __create_structure__(self, verbose=False):
         """
@@ -57,17 +57,22 @@ class UsersDB(SqliteDB):
         );"""
         self.execute(sql)
 
-    def sendMail(self, to, Object, text, env=None, verbose=False):
-        if to and os.path.isfile(self.fileconf):
-            env = env if env else {}
-            system_mail(to, sformat(text,env), sformat(Object,env), self.fileconf, verbose=verbose)
+    def getAdmins(self, verbose=False):
+        administrators = self.execute("""SELECT [mail] FROM [users] WHERE [role] ='admin';""", None, outputmode="array", verbose=verbose)
+        administrators = [ item for (item,) in administrators]
+        return administrators
 
-    def sendMailToAdmin(self, Object, text ,  env=None, verbose=False):
+    def sendMail(self, To, Object, text, env=None, verbose=False):
+        system_mail(To, text, Object, "", self.fileconf, self.filekey, env)
 
-        administrators = self.execute("""SELECT GROUP_CONCAT([mail],',') FROM [users] WHERE [role] ='admin';""", None,outputmode="scalar", verbose=verbose)
-        if administrators and  os.path.isfile(self.fileconf):
-            env = env if env else {}
-            system_mail(administrators, sformat(text,env), sformat(Object,env), self.fileconf, verbose=verbose)
+    def sendMailToAdmin(self, Object, text , env=None, verbose=False):
+        administrators = self.getAdmins()
+        system_mail(administrators, text, Object, "", self.fileconf, self.filekey, env)
+
+    def sendMailAndFeedBackAdmin(self, To, ObjectForUser, ObjectForAdmin="", text="", env=None, verbose=False):
+        ObjectForAdmin = ObjectForAdmin if ObjectForAdmin else ObjectForUser
+        system_mail(To, text, ObjectForUser, "", self.fileconf, self.filekey, env)
+        system_mail(self.getAdmins(), text, ObjectForAdmin, To, self.fileconf, self.filekey, env)
 
     def addUser(self, mail, name="", password="", role="user", enabled=False, sendmail=False, url="localhost", extra="", verbose=False):
         """
@@ -89,14 +94,10 @@ class UsersDB(SqliteDB):
         __token__ = self.execute(sql, env, outputmode="scalar", verbose=verbose)
         env["__token__"] = __token__
 
-        #send a mail to Administrators
-        administrators = self.execute("""SELECT GROUP_CONCAT([mail],',') FROM [users] WHERE [role] ='admin';""", env,
-                               outputmode="scalar", verbose=verbose)
-
-        if administrators and sendmail and isfile(self.fileconf):
-            text = ""  #some headers
+        if sendmail:
+            text = ""  # some headers
             text+= "%s"%(extra)
-            system_mail(administrators, sformat(text, env), sformat("""Check user request of {name}""", env), self.fileconf)
+            self.sendMailToAdmin( """Check user request of {name}""" , text, env )
 
         return __token__
 
@@ -104,7 +105,7 @@ class UsersDB(SqliteDB):
         """
         name
         """
-        sql ="""SELECT COUNT(*) FROM [users] WHERE [name] LIKE '{name}' OR [mail] LIKE '{mail}';"""
+        sql ="""SELECT COUNT(*) FROM [users] WHERE [mail] = '{mail}';"""
         count = self.execute(sql, {"name":name,"mail":mail}, outputmode="scalar")
         return count>0
 
@@ -138,13 +139,17 @@ class UsersDB(SqliteDB):
             }
             #Login at <a href='http://{url}/webgis/private/{mail}'>http://localhost/webgis/</a></br>
             text = """</br>
+                    Hello {name}!</br>
                     Login at <a href='{url}'>{url}</a></br>
                     Your password is:<b>{password}</b></br>
                     """
 
-            if sendmail and os.path.isfile(self.fileconf):
-                subject = subject if subject else "Credentials for the Web-Tool."
-                system_mail(mail, sformat(text, user), subject, self.fileconf,verbose=verbose)
+            #if sendmail and os.path.isfile(self.fileconf):
+            #    subject = subject if subject else "Credentials for the Web-Tool."
+            #    system_mail(mail, text, subject, self.fileconf, self.filekey, user, verbose=verbose)
+            ObjectForUser = subject if subject else "Credentials for the Web-Tool."
+            ObjectForAdmin = "New User {name} has been enabled!"
+            self.sendMailAndFeedBackAdmin(mail, ObjectForUser,ObjectForAdmin, text, user, verbose=verbose)
             return user
 
         return False
@@ -159,7 +164,7 @@ class UsersDB(SqliteDB):
         }
         sql = """
         SELECT md5([token]||strftime('%Y-%m-%d','now')) FROM [users]
-            WHERE ([name] LIKE '{username}' OR [mail] LIKE '{username}')
+            WHERE [mail] = '{username}'
             AND [token] LIKE md5([mail]||'{password}')
             AND [enabled];
         """
@@ -174,7 +179,7 @@ class UsersDB(SqliteDB):
             "__token__": token
         }
         sql = """
-        SELECT md5([token]||strftime('%Y-%m-%d','now'))='{__token__}' FROM [users] WHERE [mail] LIKE '{__username__}' LIMIT 1;
+        SELECT md5([token]||strftime('%Y-%m-%d','now'))='{__token__}' FROM [users] WHERE [mail] = '{__username__}' LIMIT 1;
         """
         return self.execute(sql, env, outputmode="scalar", verbose=False)
 
@@ -189,18 +194,23 @@ class UsersDB(SqliteDB):
             "service": service
         }
         sql = """
-              UPDATE [users] SET [token]=md5([mail]||'{password}')  WHERE [mail] LIKE '{mail}';
+              UPDATE [users] SET [token]=md5([mail]||'{password}') WHERE [mail] = '{mail}';
+              SELECT [name] FROM [users] WHERE [mail] = '{mail}';
         """
-        self.execute(sql, env, outputmode="scalar")
+        env["name"] = self.execute(sql, env, outputmode="scalar")
+
         if sendmail and os.path.isfile(self.fileconf):
 
-            Subject = """Password change for {service}"""
+            Subject = """Password change for {name} in {service}"""
 
             text = """
-            {service}<br>
-            Your password was been changed:<br>
+            <b>{name}</b> ({mail})<br>
+            Your password has been changed:<br>
             password:<b>{password}</b>
             """
-            system_mail(mail, sformat(text, env), sformat(Subject, env), self.fileconf)
+            #system_mail(mail, text, Subject, self.fileconf, self.filekey, env)
+            ObjectForUser = Subject
+            ObjectForAdmin = "User {name} changed the password"
+            self.sendMailAndFeedBackAdmin(mail, ObjectForUser, ObjectForAdmin, text, env)
 
         return password
\ No newline at end of file
